==> mingw-w64-clang-aarch64-qt6-static-6.7.0-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6DataVisualizationQml/Qt6DataVisualizationQmlTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::DataVisualizationQml" for configuration "Release"
set_property(TARGET Qt6::DataVisualizationQml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::DataVisualizationQml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6DataVisualizationQml.a"
  )

list(APPEND _cmake_import_check_targets Qt6::DataVisualizationQml )
list(APPEND _cmake_import_check_files_for_Qt6::DataVisualizationQml "${_IMPORT_PREFIX}/lib/libQt6DataVisualizationQml.a" )

# Import target "Qt6::DataVisualizationQml_resources_1" for configuration "Release"
set_property(TARGET Qt6::DataVisualizationQml_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::DataVisualizationQml_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_1/.rcc/qrc_qmake_QtDataVisualization_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::DataVisualizationQml_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::DataVisualizationQml_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_1/.rcc/qrc_qmake_QtDataVisualization_init.cpp.obj" )

# Import target "Qt6::DataVisualizationQml_resources_2" for configuration "Release"
set_property(TARGET Qt6::DataVisualizationQml_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::DataVisualizationQml_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_2/.rcc/qrc_DataVisualizationQml_raw_qml_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::DataVisualizationQml_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::DataVisualizationQml_resources_2 "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_2/.rcc/qrc_DataVisualizationQml_raw_qml_0_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-static-6.8.2-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6DataVisualizationQml/Qt6DataVisualizationQmlTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::DataVisualizationQml" for configuration "Release"
set_property(TARGET Qt6::DataVisualizationQml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::DataVisualizationQml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6DataVisualizationQml.a"
  )

list(APPEND _cmake_import_check_targets Qt6::DataVisualizationQml )
list(APPEND _cmake_import_check_files_for_Qt6::DataVisualizationQml "${_IMPORT_PREFIX}/lib/libQt6DataVisualizationQml.a" )

# Import target "Qt6::DataVisualizationQml_resources_1" for configuration "Release"
set_property(TARGET Qt6::DataVisualizationQml_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::DataVisualizationQml_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_1/.qt/rcc/qrc_qmake_QtDataVisualization_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::DataVisualizationQml_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::DataVisualizationQml_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_1/.qt/rcc/qrc_qmake_QtDataVisualization_init.cpp.obj" )

# Import target "Qt6::DataVisualizationQml_resources_2" for configuration "Release"
set_property(TARGET Qt6::DataVisualizationQml_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::DataVisualizationQml_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_2/.qt/rcc/qrc_DataVisualizationQml_raw_qml_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::DataVisualizationQml_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::DataVisualizationQml_resources_2 "${_IMPORT_PREFIX}/share/qt6/qml/QtDataVisualization/objects-Release/DataVisualizationQml_resources_2/.qt/rcc/qrc_DataVisualizationQml_raw_qml_0_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
